{% if sourcename is defined and theme_use_edit_page_button==true and
page_source_suffix %} {% set src = sourcename.split('.') %}
<div class="tocsection editthispage">
  <a href="{{ fix_edit_link_page(get_edit_provider_and_url()[1]) }}">
    <i class="fa-solid fa-pencil"></i>
    {% set provider = get_edit_provider_and_url()[0] %} {% block
    edit_this_page_text %} {% if provider %} {% trans provider=provider %}Edit
    on {{ provider }}{% endtrans %} {% else %} {% trans %}Edit{% endtrans %} {%
    endif %} {% endblock %}
  </a>
</div>

{% else %}
<!-- If there is no fix edit button function, use the PyData edit-this-button-->
{%- include "pydata_sphinx_theme/components/edit-this-page.html" -%} {% endif %}
