{% if theme_cheatsheet %}
  {% set theme_cheatsheet_title = theme_cheatsheet.get('title', 'Cheatsheet') %}
  <div class="sidebar-cheatsheets">
    <h4>{{ theme_cheatsheet_title }}</h4>
    {% set theme_cheatsheet_output_dir = theme_cheatsheet.get('output_dir') %}
    {% set theme_cheatsheet_thumbnail = theme_cheatsheet.get('thumbnail') %}
    {% set theme_cheatsheet_output = pathto(theme_cheatsheet_output_dir, 1) %}
    {% set theme_cheatsheet_thumbnail = pathto(theme_cheatsheet_thumbnail, 1) %}
    <a href="{{ theme_cheatsheet_output }}">
      <img src="{{ theme_cheatsheet_thumbnail }}" alt="{{ theme_cheatsheet_title }}" />
    </a>
  </div>
{% endif %}
