@import "ansys-sphinx-theme-variable.css";

/**
* Sphinx gallery output cell
*/

.highlight pre {
  font-size: 0.9em;
}

/**
* Sphinx gallery download button text
*/

a > code.download {
  font-family: var(--pst-font-family-base);
  color: var(--pst-color-link);
  text-decoration: none;
  font-weight: normal;
}

div.sphx-glr-download a,
div.sphx-glr-download a:hover {
  background-image: none;
  color: var(--ast-sphinx-gallery-download-text);
  text-decoration: none;
  border-radius: 4px;
  height: 36px;
  padding: 0px 16px;
  display: flex;
  align-items: flex-start;
  justify-content: center;
  flex-wrap: wrap;
  flex-direction: column;
}
div.sphx-glr-download code.download,
div.sphx-glr-download a.reference.download:before {
  color: var(--ast-sphinx-gallery-download-text);
}

a.reference.download:before {
  color: var(--ast-color-text);
}

div.sphx-glr-download a:hover {
  background-color: var(--ast-sphinx-gallery-download-background-hover);
}

div.sphx-glr-download a {
  background-color: var(--ast-sphinx-gallery-download-background);
  color: var(--ast-sphinx-gallery-download-text);
}

div.sphx-glr-footer {
  text-align: center;
  display: flex;
  gap: 10px;
  align-content: center;
  justify-content: center;
  flex-wrap: wrap;
  flex-direction: row;
}

div.sphx-glr-download {
  margin: 0px;
}
