@import "https://cdn.jsdelivr.net/npm/docs-searchbar.js@latest/dist/cdn/docs-searchbar.min.css";
@import "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css";

div[data-ds-theme] .searchbox {
  overflow-y: scroll;
  margin: auto;
}

.docs-searchbar-suggestion--category-header {
  background-color: var(--ast-suggestion-header-background);
  border-radius: 4px;
  text-align: left;
  color: var(--ast-catagory-header-text) !important;
  width: 680px;
  padding: 4px;
}

.dsb-suggestions {
  width: 100%;
  max-width: 140%;
}

div[data-ds-theme] .meilisearch-autocomplete .dsb-dropdown-menu {
  max-width: 1200px;
  min-width: 800px;
  width: 800px;
}
div[data-ds-theme] .meilisearch-autocomplete .docs-searchbar-suggestion {
  width: 100%;
}

div[data-ds-theme] .searchbox input {
  height: 32px;
  border-radius: 8px;
  font-size: 18px;
  font-family: "Open Sans", sans-serif;
  box-shadow: 0px 0px 8px darkgrey;
}

.docs-searchbar-footer {
  display: none;
}

.docs-searchbar-footer {
  display: none;
}

[class*="docs-searchbar-suggestion"] {
  text-decoration: none;
}

.docs-searchbar-suggestion--highlight {
  box-shadow: none !important;
}

div[data-ds-theme] .meilisearch-autocomplete {
  text-align: center;
  color: var(--pst-color-text-base);
}

.form-control:focus,
.form-control:focus-visible,
.form-control {
  background-color: var(--ast-search-bar-enable-background);
  color: var(--ast-search-bar-enable-text);
  font-size: 14px;
  outline-color: var(--ast-search-bar-enable-border);
  border: 0.5px solid var(--ast-search-bar-enable-border);
  width: 670px;
  max-width: 200%;
  height: 40px;
  margin-left: 5px;
}

.search-button__wrapper.show input,
.search-button__wrapper.show svg {
  font-size: 14px;
}

.bd-search .search-button__kbd-shortcut {
  background-color: var(--ast-search-bar-enable-background) !important;
  box-shadow: none !important;
  height: 40px;
  display: flex;
  flex-wrap: wrap;
  align-content: center;
}

.index-select {
  color: var(--ast-search-bar-enable-text);
  background: var(--ast-search-bar-enable-background);
  height: 40px;
  font-size: 14px;
  font-family: "Open Sans", sans-serif;
  border: 0.5px solid var(--ast-search-bar-enable-border);
  border-radius: 4px;
  box-shadow: none;
  padding: 0px 8px;
  margin-left: 2px;
}
:focus-visible {
  outline: none;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu
  [class^="dsb-dataset-"] {
  position: relative;
  border: 1px solid #d9d9d9;
  background: var(--ast-search-bar-enable-background);
  border-radius: 4px;
  padding: 0 8px 8px;
}
div[data-ds-theme] .meilisearch-autocomplete .dsb-dropdown-menu {
  max-height: 500px !important;
  border: 1px solid #ccc;
  left: -30px;
  overflow-y: auto;
}

div[data-ds-theme] .meilisearch-autocomplete .docs-searchbar-suggestion {
  background: var(--ast-search-bar-enable-background);
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .docs-searchbar-suggestion--highlight {
  color: var(--ast-suggestion-text-color) !important;
  font-weight: 900;
  background: transparent;
  padding: 0 0.05em;
}

.meilisearch-autocomplete .docs-searchbar-suggestion--text {
  color: var(--ast-catagory-suggestion-text);
  font-size: 12px;
  line-height: var(--ast-global-line-height);
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .docs-searchbar-suggestion--subcategory-column {
  width: None;
  text-align: left;
}

.meilisearch-autocomplete .docs-searchbar-suggestion--category-header {
  width: 100%;
  padding: 4px 8px;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .docs-searchbar-suggestion--content {
  display: block;
}

div[data-ds-theme] .meilisearch-autocomplete .docs-searchbar-suggestion--title {
  margin-bottom: 4px;
  color: var(--ast-search-bar-enable-text);
  font-size: 0.9em;
  font-weight: 700;
  width: 100%;
}

/**
* Styling the scrollbar
*/
div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu::-webkit-scrollbar {
  width: 0.5rem;
  height: 0.5rem;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu::-webkit-scrollbar-thumb {
  background: var(--ast-search-bar-enable-background);
  border-radius: inherit;
}

div[data-ds-theme]
  .meilisearch-autocomplete
  .dsb-dropdown-menu::-webkit-scrollbar-track {
  background: var(--ast-search-bar-enable-background);
}

.bd-search {
  gap: 8px;
  background-color: var(--ast-search-bar-enable-background);
  border: 0px solid var(--ast-search-bar-enable-border);
  margin-bottom: 300px;
}
#search-icon {
  font-size: 24px;
  width: 24px;
  height: 24px;
  color: var(--ast-search-bar-enable-text);
}

.form-control:focus {
  box-shadow: none;
}
