/* Provided by the Sphinx base theme template at build time,
styles exclusively for the ansys-sphinx-theme classes. */

@import "ansys-sphinx-theme-variable.css";

/**
* Breadcrumbs
*/

ul.bd-breadcrumbs li.breadcrumb-item {
  padding: 0px;
  font-size: 12px;
  display: flex;
}

ul.bd-breadcrumbs li.breadcrumb-item:hover {
  text-decoration: underline;
  font-size: 12px;
}

ul.bd-breadcrumbs li.breadcrumb-item a {
  color: var(--ast-navbar-color);
  font-size: 12px;
}

ul.bd-breadcrumbs li.breadcrumb-item a:hover {
  text-decoration: underline;
}

ul.bd-breadcrumbs li.breadcrumb-item a:active {
  color: var(--ast-color-text);
}

.breadcrumb-item.active {
  color: var(--ast-color-text);
}

/**
* Version warning announcement
*/

#announcement_msg {
  display: flex;
  justify-content: center;
  position: relative;
  width: 100%;
  padding: 0.5rem 12.5%;
  text-align: center;
}

#announcement_msg :after {
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  background-color: rgb(223, 95, 114);
  opacity: 0.2;
  content: "";
  z-index: -1;
}

#announcement_msg :empty {
  display: none;
}

#announcement_msg p {
  font-weight: bold;
  margin: auto;
  color: black;
}

html[data-theme="dark"] #announcement_msg :after {
  background-color: lightpink;
  opacity: 0.5;
}

#announcement_msg a {
  color: #1e6ddc;
}

.sidebar-cheatsheets {
  text-align: center;
}

.sidebar-cheatsheets h4 {
  font-weight: var(--pst-sidebar-header-font-weight) !important;
  font-size: var(--pst-sidebar-header-font-size) !important;
  margin-bottom: 0.5rem;
}

.sidebar-cheatsheets a {
  display: inline-flex;
  border: 0.5px solid var(--pst-color-border);
  padding: 0.25rem;
  max-width: 80%;
}

.sidebar-cheatsheets a:hover {
  background-color: var(--pst-color-border);
  color: var(--pst-color-text-base);
}

.sidebar-cheatsheets img {
  padding: 0rem;
}

.bd-sidebar-primary {
  padding: 0.5rem;
}
