@import "../design-style.4045f2051d55cab465a707391d5b2007.min.css";

/**
* sphinx design button
*/

.sd-btn {
  font-size: var(--ast-sphinx-design-font-size);
  font-weight: 400;
  font-family: var(--ast-sphinx-design-font-family);
  padding: 8px 16px;
  border-radius: var(--ast-sphinx-design-border-radius);
}

.sd-btn-secondary {
  font-size: var(--ast-sphinx-design-font-size);
  font-weight: 400;
  font-family: var(--ast-sphinx-design-font-family);
  padding: 8px 16px;
  border-radius: var(--ast-sphinx-design-border-radius);
  color: var(--sd-color-secondary-text);
  background-color: var(--sd-color-secondary);
  border-color: var(--sd-color-secondary);
}

blockquote {
  background-color: var(--pst-color-background);
}

/* Media query for medium-sized screens */
@media screen and (max-width: 768px) {
  .sd-card .sd-card-header {
    font-size: var(--pst-font-size-h6);
  }
}

/* Media query for small-sized screens */
@media screen and (max-width: 576px) {
  .sd-card .sd-card-header {
    font-size: var(--pst-font-size-h5);
  }
  .sd-card {
    padding: 4px;
  }
}
/**
* Sphinx-design dropdown
*/

.bd-content details.sd-dropdown:not([open]) > .sd-card-header {
  border-radius: var(--ast-sphinx-design-border-radius);
}

.bd-content details.sd-dropdown {
  color: var(--ast-dropdown-text-color);
  width: fit-content;
  min-width: 400px;
}

.bd-content details.sd-dropdown summary.sd-summary-title {
  font-family: var(--ast-sphinx-design-font-family);
  font-size: var(--ast-sphinx-design-font-size);
  background: var(--ast-color-sphinx-design-background) !important;
  border: 1px solid var(--ast-dropdown-border-color) !important;
  border-radius: var(--ast-sphinx-design-border-radius);
  padding: 8px 12px;
  text-align: left;
}

.bd-content details.sd-dropdown summary.sd-summary-title:hover {
  background-color: var(--ast-color-hover-card-background) !important;
  border: 1px solid var(--ast-dropdown-border-color-hover) !important;
  border-radius: var(--ast-sphinx-design-border-radius);
}

.bd-content
  details.sd-dropdown
  summary.sd-card-header
  + div.sd-summary-content {
  background-color: var(--ast-color-sphinx-design-background);
  border-left: none !important;
}

.bd-content
  details.sd-dropdown
  .sd-summary-title:active
  + div.sd-summary-content:active {
  background-color: var(--ast-color-enable-card-background);
  border-color: var(--ast-color-enable-border);
}

.bd-content
  details.sd-dropdown
  .sd-summary-title:hover
  + div.sd-summary-content:hover {
  background-color: var(--ast-color-hover-card-background);
  border-color: var(--ast-color-hover-border);
  border-left: none;
}

.bd-content
  details.sd-dropdown
  summary.sd-summary-title:focus
  + div.sd-summary-content:focus {
  background-color: var(--ast-color-sphinx-design-background);
  border-radius: var(--ast-sphinx-design-border-radius);
  border-color: var(--pst-color-border);
  border-left: none;
}

details.sd-dropdown summary.sd-card-header + div.sd-summary-content {
  color: var(--ast-color-sphinx-design-primary);
  font-family: var(--ast-sphinx-design-font-family);
  font-size: var(--ast-sphinx-design-font-size);
}

/**
* Sphinx-design tab
*/

.bd-content .sd-tab-set > label {
  font-family: var(--ast-sphinx-design-font-family);
  padding: 12px 0px;
  border-style: none none solid none;
  color: var(--ast-color-sphinx-design-primary);
  font-size: var(--ast-sphinx-design-font-size);
  margin-inline-end: 16px;
  transform: none;
  margin-bottom: 1px;
}

.bd-content .sd-tab-set > input:checked + label:hover,
.bd-content .sd-tab-set > input:not(:checked, :focus-visible) + label:hover {
  color: var(--ast-color-sphinx-design-primary);
  font-family: var(--ast-sphinx-design-font-family);
}

.bd-content .sd-tab-set > input + label:focus-visible,
.bd-content
  .sd-tab-set
  > input:not(:checked, :focus-visible)
  + label:focus-visible {
  background-color: var(--ast-background-tab-focus);
  border-color: transparent transparent var(--ast-tab-border-color-hover)
    transparent;
  border-width: 0px 0px 2px 0px;
  text-decoration-line: none;
}

.bd-content .sd-tab-set > input:checked + label {
  background-color: transparent;
  border-color: transparent transparent var(--ast-tab-border-color-active)
    transparent;
  border-width: 0px 0px 2px 0px;
  border-style: none none solid none;
  transform: none;
}

.bd-content .sd-tab-set > input:checked + label:hover {
  background-color: var(--ast-background-tab-hover);
  border-color: transparent transparent var(--ast-tab-border-color-hover)
    transparent;
  border-width: 0px 0px 2px 0px;
}

.bd-content .sd-tab-set > input:not(:checked, :focus-visible) + label {
  background-color: transparent;
  border-color: transparent transparent var(--ast-tab-border-color) transparent;
  border-width: 0px 0px 1px 0px;
  text-decoration-line: none;
  font-weight: normal;
}

.bd-content .sd-tab-set > input:not(:checked, :focus-visible) + label:hover {
  background-color: var(--ast-background-tab-hover);
  border-color: transparent transparent var(--ast-tab-border-color-hover)
    transparent;
  border-width: 0px 0px 2px 0px;
  border-style: none none solid none;
  text-decoration: none;
}

.bd-content .sd-tab-set .sd-tab-content {
  border: none;
  font-family: var(--ast-sphinx-design-font-family);
  font-size: var(--ast-sphinx-design-font-size);
  color: var(--ast-color-sphinx-design-primary);
}

/* Media query for medium-sized screens */
@media screen and (max-width: 768px) {
  .sd-tab-set > input:not(.focus-visible) + label {
    font-size: 14px;
  }
}

/* Media query for small-sized screens */
@media screen and (max-width: 576px) {
  .sd-tab-set > input:not(.focus-visible) + label {
    font-size: 12px;
  }
}

/**
* Sphinx-design card
*/

.bd-content .sd-card .sd-card-body,
.bd-content .sd-card .sd-card-footer {
  font-size: var(--ast-sphinx-design-font-size);
  border: none;
  background-color: var(--ast-color-sphinx-design-background);
  font-family: var(--ast-sphinx-design-font-family);
  color: var(--ast-color-sphinx-design-primary);
  border-radius: 8px;
}

.bd-content .sd-card .sd-card-title,
.bd-content .sd-card .sd-card-header {
  font-size: 16px;
  border: none;
  background-color: var(--ast-color-sphinx-design-background);
  font-family: var(--ast-sphinx-design-font-family);
}

.bd-content .sd-card {
  border: none;
  border-radius: 8px;
  box-shadow: var(--ast-box-shadow-hover) !important;
  color: var(--ast-color-sphinx-design-primary);
  background-color: var(--ast-color-sphinx-design-background);
}

.bd-content .sd-card:hover {
  box-shadow: var(--ast-box-shadow-hover) !important;
}

.sd-hide-link-text:focus {
  outline: none;
  box-shadow: none;
}

.bd-content .sd-card .sd-stretched-link:focus-visible:after {
  outline: none;
  box-shadow: var(--ast-ring-shadow-focused);
}
