/* Provided by the Sphinx base theme template at build time */

@import "../basic.css";
@import "../sg_gallery.css";
@import "ansys-sphinx-theme-variables.css";
@import "pydata-sphinx-theme-custom.css";
@import "breadcrumbs.css";
@import "meilisearch.css";
@import "sphinx-design.css";
@import "table-custom.css";
@import "sphinx-gallery.css";

/*
* Code cell
*/
.xref.std.std-ref {
  color: var(--pst-color-inline-code);
  font-family: "Inconsolata";
  font-weight: normal;
  font-style: italic;
  padding: 0.1rem 0.25rem;
  padding-top: 0.1rem;
  padding-right: 0.25rem;
  padding-bottom: 0.1rem;
  padding-left: 0.25rem;
  font-size: 90%;
  background-color: var(--pst-color-on-surface);
  border: 1px solid var(--pst-color-border);
  border-radius: 0.25rem;
}

/* Reduce empty-space around Notes and Examples headings */
p.rubric {
  margin-top: 0.75em;
  margin-bottom: 0.75em;
}

/*
* Autosummary
*/

.autosummary tr:nth-child(odd),
.autosummary tr:nth-child(even) {
  background-color: var(--pst-color-background);
}
