/*
 * Overrides the default CSS for https://nbsphinx.readthedocs.io/ extension.
 */

/*
 * Do not display the caption paragraph in the body content for 'nbgallery'
 */
.toctree-wrapper > p.caption {
  display: none;
}
