/**
* Table
*
* the table variables.
*/

.table {
  --bs-table-bg: var(--ast-color-table-background);
  border-spacing: 0;
  border-collapse: separate;
  overflow: hidden;
  vertical-align: middle;
  overflow-y: scroll;
  scrollbar-width: none;
  -ms-overflow-style: none;
  border-color: var(--ast-table-outer-border);
  background-color: var(--ast-color-table-background);
}

tbody,
td,
tfoot,
th,
thead,
tr {
  border-bottom: 1px solid var(--ast-color-table-inner-border);
  background-color: var(--ast-color-table-background);
  font-family: var(--ast-font-family-base);
  font-size: var(--ast-table-font-size);
}

.table > :not(caption) > * > * {
  padding: 0px 16px;
}

/**
* Table header
*/
th {
  line-height: 40px;
  color: var(--ast-color-table-header-text) !important;
  font-size: var(--ast-table-header-font-size) !important;
}

/**
* Table body
*/

tr {
  line-height: var(--ast-global-line-height);
  height: 56px;
  color: var(--ast-color-table-cell-text);
}

/**
* Table hover
*/

tbody :hover,
td :hover,
tfoot :hover,
th :hover,
thead :hover,
tr :hover {
  background-color: var(--ast-color-table-row-hover-bg);
  font-family: var(--ast-font-family-base);
}

.table :hover {
  background-color: var(--ast-color-table-row-hover-bg);
}

/**
* Table active
*/

.table :active {
  background-color: var(--ast-color-table-active-bg);
}
/**
* Table dataframes
*/

table.dataframe tr {
  font-size: var(--ast-table-font-size);
  line-height: 56px;
  color: var(--ast-color-table-cell-text);
}

table.dataframe th {
  font-size: var(--ast-table-font-size);
  line-height: 40px;
  color: var(--ast-color-table-header-text) !important;
}

table.dataframe :hover {
  background-color: var(--ast-color-table-row-hover-bg);
  font-family: var(--ast-font-family-base);
}

table.dataframe :active {
  background-color: var(--ast-color-table-active-bg);
  font-family: var(--ast-font-family-base);
}

table.dataframe {
  background-color: var(--ast-color-table-background);
}

.table td ~ td,
.table td ~ th,
.table th ~ td,
.table th ~ th,
.bd-content .nboutput .output_area.rendered_html table.dataframe th ~ td {
  border-left: 1px solid var(--ast-color-table-inner-border);
}
