/*Contains variables for colors and fonts used in the theme*/
@import url("https://fonts.googleapis.com/css2?family=Lato:ital,wght@0,400;0,700;0,900;1,400;1,700;1,900&family=Open+Sans:ital,wght@0,400;0,600;1,400;1,600&display=swap");

@font-face {
  font-family: "Source Sans Pro Light";
  src: url(../fonts/SourceSansPro-Light.ttf);
}

@font-face {
  font-family: "Source Sans Pro";
  src: url(../fonts/SourceSansPro-Regular.ttf);
}

:root {
  /** Ansys specific changes to the theme */

  /**
  * Ansys Font family
  *
  * These are adapted from https://systemfontstack.com/
  */
  --pst-font-family-base-system: -apple-system, BlinkMacSystemFont, Segoe UI,
    "Helvetica Neue", Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji,
    Segoe UI Symbol;
  --pst-font-family-monospace-system: "SFMono-Regular", Menlo, Consolas, Monaco,
    Liberation Mono, Lucida Console, monospace;

  --pst-font-family-base: "Source Sans Pro", sans-serif,
    var(--pst-font-family-base-system);
  --pst-font-family-heading: "Source Sans Pro", sans-serif,
    var(--pst-font-family-base-system);
  --pst-font-family-monospace: monospace, Courier,
    var(--pst-font-family-monospace-system);

  /**
  * Ansys compatible colors
  *
  * Colors are defined in rgb string way, "red, green, blue"
  */
  --ansysGold: rgb(255, 183, 27); /* #FFB71B */
  --ansysBronze: rgb(200, 146, 17); /* #C89211 */
  --pythonBlue: rgb(57, 114, 161); /* #3972a1 */
  --pst-font-size-h1: 36px;
  --pst-font-size-h2: 32px;
  --pst-font-size-h3: 28px;
  --pst-font-size-h4: 20px;
  --pst-font-size-h5: 14px;
  --pst-font-size-h6: 11px;
  --ast-global-line-height: 24px;
  --bs-nav-link-font-size: 14px;
  --bs-navbar-color: var(--bs-ast-navbar-color);
  --ast-font-sidebar-header: var(--pst-font-size-h5);
  /**
  * table font sizes
  */
  --pst-table-font-size: 14px;
  --pst-table-header-font-size: 12px;

  /**
  * sphinx design font sizes
  */

  --ast-sphinx-design-font-size: 14px;
  --ast-sphinx-design-font-family: "Open Sans", sans-serif;
  --ast-sphinx-design-border-radius: 4px;

  /**
* admonitions
*/
  --ast-admonitions-font-size: 14px;
  --ast-admonitions-padding: 8px 16px;
  --ast-admonitions-border-radius: 8px;
  --ast-admonitions-icon-size: 15px;
  --ast-admonition-icon-height: 24px;
  --ast-admonition-icon-width: 24px;
  --ast-admonition-icon-margin-left: 8px;
}

html[data-theme="light"] {
  /**
  * main colors
  */
  --ast-color-text: #353535;
  --ast-color-active-text: #353535;
  --ast-color-hover-text: #353535;
  --pst-color-background: #f7f7f7;
  --pst-color-primary: #353535;
  --pst-color-secondary: #f2f2f2;
  --pst-color-success: rgb(40, 167, 69);
  --pst-color-text-base: rgb(0, 0, 0);
  --pst-color-text-muted: #353535;
  --pst-color-border: #686868;
  --pst-color-shadow: rgb(216, 216, 216);
  --pst-color-info: var(--pst-color-link);
  --pst-color-link-hover: #686868;

  /**
  * Navigation colors
  */
  --pst-color-on-background: var(
    --pst-color-background
  ); /* important tag from pydata-sphinx-theme */
  --ast-navbar-color: #686868;
  --ast-navbar-hover-color: var(--ast-color-hover-text);
  --ast-navbar-active-color: var(--ast-color-active-text);
  --ast-navbar-active-border-color: #000000;
  --ast-ring-shadow-focused: 0px 0px 0px 2px #ffffff, 0px 0px 0px 4px #1a78c2;

  /**
  * sidebar colors
  */
  --ast-sidebar-primary-text: var(--ast-color-text);
  --ast-sidebar-hover-background: #ececec;
  --ast-sidebar-active-background: #d9d9d9;

  /**
  * depth colors
  */
  /* --pst-color-on-background: rgb(0, 0, 0); */
  --pst-color-on-surface: #f2f2f2;

  /**
  * table
  */
  --ast-color-table-background: #ffffff;
  --ast-color-enabled-table-text: var(--ast-color-text);
  --ast-color-table-row-hover-bg: #ececec;
  --ast-color-table-active-bg: #e9f4fe;
  --ast-color-table-header-text: #686868;
  --ast-color-table-cell-text: var(--ast-color-text);
  --ast-table-outer-border: #ececec;
  --ast-color-table-inner-border: #ececec;

  --pst-color-panel-background: var(--pst-color-on-background);

  /**
  * layout
  */

  --ast-color-link: #1e6ddc;
  --ast-color-link-hover: #1856af;
  --ast-color-link-active: #104188;
  --ast-color-link-visited: #9a33cb;
  --ast-color-link-visited-hover: #7f29a2;
  --ast-color-inline-code: var(
    --pst-color-text-muted
  ); /* inline code color for docutils (_base.scss)*/
  --pst-color-target: rgb(255, 255, 255);

  /**
  * color for sphinx-gallery-code output
  */
  --pst-color-codecell: #fafae2;
  --pst-color-codeout: var(--pst-color-inline-code);
  --pst-color-sig: #0965c8;
  --pst-color-code-s1: #b35000;
  --pst-color-code-c1: #095d0a;

  --ast-sphinx-gallery-download-background: #1a1a1a;
  --ast-sphinx-gallery-download-background-hover: #353535;
  --ast-sphinx-gallery-download-text: #fdfdfd;

  /**
  * sphinx design
  */
  --sd-color-primary: var(--pst-color-text-base);
  --ast-color-enable-card-background: #ffffff;
  --ast-color-enable-border: #d9d9d9;
  --ast-color-hover-card-background: #ececec;
  --ast-dropdown-border-color: #d9d9d9;
  --ast-dropdown-border-color-hover: #8e8e8e;

  --ast-color-sphinx-design-primary: #353535;
  --ast-color-sphinx-design-background: #ffffff;
  --sd-color-primary: #141414;
  --sd-color-primary-highlight: var(--ast-color-sphinx-design-primary);
  --sd-color-primary-text: var(--ast-color-sphinx-design-background);
  --sd-color-secondary: var(--ast-color-sphinx-design-background);
  --sd-color-secondary-text: #141414;
  --sd-color-secondary-highlight: var(--ast-color-hover-card-background);
  --sd-color-secondary-bg: var(--ast-color-sphinx-design-background);
  --ast-sd-bg-secondary-hover: var(--ast-color-hover-card-background);
  --ast-background-tab-focus: #d9d9d9;
  --ast-background-tab-hover: #ececec;
  --ast-tab-border-color: #d9d9d9;
  --ast-tab-border-color-hover: #8e8e8e;
  --ast-tab-border-color-active: #000000;
  --ast-dropdown-text-color: #686868;
  --ast-box-shadow-active: 0px 1px 2px 0px rgba(0, 0, 0, 0.08),
    0px 2px 4px 0px rgba(0, 0, 0, 0.12);
  --ast-box-shadow-hover: 0px 1px 2px 0px rgba(0, 0, 0, 0.08),
    0px 4px 8px 2px rgba(0, 0, 0, 0.12);
  /**
  * search hide match
  */
  --pst-color-search-match: #91969b;

  /**
  * admonitions
  */
  --ast-admonition-neutral-icon: #353535;
  --ast-admonition-neutral-border: #686868;
  --ast-admonition-info-icon: #1a78c2;
  --ast-admonition-info-border: #1a78c2;
  --ast-admonition-success-icon: #006600;
  --ast-admonition-success-border: #008000;
  --ast-admonition-warning-icon: #caad2a;
  --ast-admonition-warning-border: #fdd835;
  --ast-admonition-danger-icon: #b72e2a;
  --ast-admonition-danger-border: #e53935;
  --ast-admonitions-color: var(--ast-color-text);

  /**
  * search bars
  */
  --ast-search-bar-enable-background: #ffffff;
  --ast-search-bar-enable-border: #d9d9d9;
  --ast-search-bar-enable-text: #686868;
  --ast-suggestion-header-background: #d9d9d9;
  --ast-catagory-header-text: #353535;
  --ast-catagory-suggestion-text: #8e8e8e;
  --ast-suggestion-text-color: #000000;

  /**
  * dropdown header
  */
  --ast-dropdown-header-border: #d9d9d9;
}

html[data-theme="dark"] {
  /**
  * main colors
  */
  --ast-color-text: #ececec;
  --ast-color-active-text: #d5d5d5;
  --ast-color-hover-text: #d5d5d5;
  --pst-color-primary: #ececec;
  --pst-color-secondary: #353535;
  --pst-color-success: rgb(72, 135, 87);
  --pst-color-text-base: rgb(201, 209, 217);
  --pst-color-text-muted: rgb(192, 192, 192);
  --pst-color-border: rgb(192, 192, 192);
  --pst-color-shadow: rgb(104, 102, 102);
  --pst-color-background: #1a1a1a;
  --pst-color-surface: rgb(41, 41, 41);
  --pst-color-on-surface: rgb(55, 55, 55);
  --pst-color-info: var(--pst-color-secondary);
  --pst-color-link-hover: #b3b3b3;

  /**
  * extensions
  */

  --pst-color-panel-background: var(--pst-color-on-background);

  /**
  * Navigation colors
  */

  --pst-color-on-background: var(
    --pst-color-background
  ); /* important tag from pydata-sphinx-theme */
  --ast-navbar-color: #8e8e8e;
  --ast-navbar-hover-color: var(--ast-color-hover-text);
  --ast-navbar-active-color: var(--ast-color-active-text);
  --ast-navbar-active-border-color: #ffffff;
  --ast-nav-link-color: var(--ast-navbar-color);
  --ast-ring-shadow-focused: 0px 0px 0px 2px #282828, 0px 0px 0px 4px #4dabf5;

  /**
  * sidebar colors
  */
  --ast-sidebar-primary-text: var(--ast-color-text);
  --ast-sidebar-hover-background: #3d3d3d;
  --ast-sidebar-active-background: #2d2d2d;
  --ast-color-inline-code: var(
    --pst-color-text-muted
  ); /* inline code color for docutils (_base.scss)*/

  /**
  * layout
  */

  --ast-color-link: #1e6ddc;
  --ast-color-link-hover: #1856af;
  --ast-color-link-active: #579ce5;
  --ast-color-link-visited: #c58ac5;
  --ast-color-link-visited-hover: #a96ba9;
  --pst-color-target: rgb(71, 39, 0);

  /**
  * color for sphinx-gallery-code output
    */
  --pst-color-codecell: #353535;
  --pst-color-codeout: #f2f4f6;
  --pst-color-sig: #d6ab1e;
  --pst-color-code-s1: #d79a60;
  --pst-color-code-c1: #8fb842;

  --ast-sphinx-gallery-download-background: #ffffff;
  --ast-sphinx-gallery-download-background-hover: #ececec;
  --ast-sphinx-gallery-download-text: #1a1a1a;

  /**
  * table hovering
  */
  --ast-color-table-background: #353535;
  --ast-color-enabled-table-text: #ececec;
  --ast-color-table-row-hover-bg: #3d3d3d;
  --ast-color-table-header-text: #d3d3d3;
  --ast-color-table-cell-text: #ececec;
  --ast-color-table-active-bg: #3d3d3d;
  --ast-table-outer-border: #d3d3d3;
  --ast-color-table-inner-border: #d3d3d3;

  /**
  * search hide match
  */
  --pst-color-search-match: var(--pst-color-primary);

  /**
  * sphinx design
  */

  --sd-color-primary: var(--pst-color-text-base);
  --ast-color-enable-card-background: #282828;
  --ast-color-enable-border: #e5e5e5;
  --ast-color-hover-card-background: #3d3d3d;
  --ast-dropdown-border-color: #3d3d3d;
  --ast-dropdown-border-color-hover: #8e8e8e;

  --ast-color-sphinx-design-primary: #ececec;
  --ast-color-sphinx-design-background: #282828;
  --sd-color-primary: #d5d5d5;
  --sd-color-primary-highlight: var(--ast-color-sphinx-design-primary);
  --sd-color-primary-text: var(--ast-color-sphinx-design-background);
  --sd-color-secondary: var(--ast-color-sphinx-design-background);
  --sd-color-secondary-text: #d5d5d5;
  --sd-color-secondary-highlight: var(--ast-color-hover-card-background);
  --sd-color-secondary-bg: var(--ast-color-sphinx-design-background);
  --ast-sd-bg-secondary-hover: var(--ast-color-hover-card-background);
  --ast-background-tab-focus: #2d2d2d;
  --ast-background-tab-hover: #3d3d3d;
  --ast-tab-border-color: #e5e5e5;
  --ast-tab-border-color-hover: #8e8e8e;
  --ast-tab-border-color-active: #ffffff;
  --ast-dropdown-text-color: #e5e5e5;
  --ast-box-shadow-active: 0px 1px 2px 0px rgba(0, 0, 0, 0.4),
    0px 2px 4px 0px rgba(0, 0, 0, 0.48);
  --ast-box-shadow-hover: 0px 1px 2px 0px rgba(0, 0, 0, 0.4),
    0px 4px 8px 2px rgba(0, 0, 0, 0.48);

  /**
* admonitions
*/
  --ast-admonition-neutral-icon: #ececec;
  --ast-admonition-neutral-border: #8e8e8e;
  --ast-admonition-info-icon: #1a78c2;
  --ast-admonition-info-border: #1856af;
  --ast-admonition-success-icon: #006600;
  --ast-admonition-success-border: #147914;
  --ast-admonition-warning-icon: #caad2a;
  --ast-admonition-warning-border: #bba12e;
  --ast-admonition-danger-icon: #b72e2a;
  --ast-admonition-danger-border: #b12422;
  --ast-admonitions-color: var(--ast-color-text);

  /**
  * search bars
  */
  --ast-search-bar-enable-background: #2d2d2d;
  --ast-search-bar-enable-border: #3d3d3d;
  --ast-search-bar-enable-text: #d3d3d3;
  --ast-suggestion-header-background: #3d3d3d;
  --ast-catagory-header-text: #ececec;
  --ast-catagory-suggestion-text: #686868;
  --ast-suggestion-text-color: #ffffff;

  /**
  * dropdown header
  */
  --ast-dropdown-header-border: #3d3d3d;
}

/**
* font sizes
* body and content
*/

body {
  font-family: "Open Sans", sans-serif;
  line-height: var(--ast-global-line-height);
  font-size: 14px;
  color: var(--ast-color-text);
}

h1,
h2 {
  color: var(--pst-color-text-base);
}
